@@ -74,7 +74,7 @@ MActionEditDialog::MActionEditDialog(TQWidget *parent, Action::Type action)
 	_methods->setFocusPolicy(StrongFocus);
 	_methods->insertItem(i18n("TDE (default)"));
 	l_method->setBuddy(_methods);
-	connect(_methods, SIGNAL(activated(int)), SLOT(slotMethodChange(int)));
+	connect(_methods, TQ_SIGNAL(activated(int)), TQ_SLOT(slotMethodChange(int)));
 
 	// command label
 	l_command = new TQLabel(i18n("Enter a custom command:"), gb_method);
@@ -92,16 +92,16 @@ MActionEditDialog::MActionEditDialog(TQWidget *parent, Action::Type action)
 	i_commandBeforeActionPause->setSpecialValueText(i18n("No pause"));
 	i_commandBeforeActionPause->setSuffix(" " + i18n("second(s)"));
 	b_testCommandBeforeAction = new KPushButton(KStdGuiItem::test(), gb_commandBeforeAction, "KPushButton::b_testCommandBeforeAction");
-	connect(b_testCommandBeforeAction, SIGNAL(clicked()), SLOT(slotTestCommandBeforeAction()));
+	connect(b_testCommandBeforeAction, TQ_SIGNAL(clicked()), TQ_SLOT(slotTestCommandBeforeAction()));
 	connect(
-		c_runCommandBeforeAction, SIGNAL(toggled(bool)),
-		i_commandBeforeAction, SLOT(setEnabled(bool)));
+		c_runCommandBeforeAction, TQ_SIGNAL(toggled(bool)),
+		i_commandBeforeAction, TQ_SLOT(setEnabled(bool)));
 	connect(
-		c_runCommandBeforeAction, SIGNAL(toggled(bool)),
-		i_commandBeforeActionPause, SLOT(setEnabled(bool)));
+		c_runCommandBeforeAction, TQ_SIGNAL(toggled(bool)),
+		i_commandBeforeActionPause, TQ_SLOT(setEnabled(bool)));
 	connect(
-		c_runCommandBeforeAction, SIGNAL(toggled(bool)),
-		b_testCommandBeforeAction, SLOT(setEnabled(bool)));
+		c_runCommandBeforeAction, TQ_SIGNAL(toggled(bool)),
+		b_testCommandBeforeAction, TQ_SLOT(setEnabled(bool)));
 
 	MTip *t_progs = new MTip(MTip::Warning, gb_south);
 	t_progs->setTipText(
@@ -121,7 +121,7 @@ MActionEditDialog::MActionEditDialog(TQWidget *parent, Action::Type action)
 		)
 	);
 
-	connect(this, SIGNAL(okClicked()), SLOT(slotOKClicked()));
+	connect(this, TQ_SIGNAL(okClicked()), TQ_SLOT(slotOKClicked()));
 
 	Action::Method m = Action::Method_TDE;
 	TQString c;
