@@ -67,7 +67,7 @@ MMainWindow::MMainWindow()
 	_delayType(DelayType_Now)
 {
 	_instance = this;
-	connect(kapp, SIGNAL(aboutToQuit()), SLOT(slotAboutToQuit()));
+	connect(kapp, TQ_SIGNAL(aboutToQuit()), TQ_SLOT(slotAboutToQuit()));
 
 	// init date/time
 	dt_end = TQDateTime();
@@ -75,7 +75,7 @@ MMainWindow::MMainWindow()
 
 	// action timeout timer
 	_timer = new TQTimer(this);
-	connect(_timer, SIGNAL(timeout()), SLOT(slotCheckTime()));
+	connect(_timer, TQ_SIGNAL(timeout()), TQ_SLOT(slotCheckTime()));
 
 	// init widgets
 	setCentralWidget(initWidgets());
@@ -477,7 +477,7 @@ void MMainWindow::initMainMenu()
 		_statisticsAction->setEnabled(false);
 
 // TODO: 2.0: improve kiosk support
-	KStdAction::quit(this, SLOT(slotQuit()), actionCollection())->plug(pm_file);
+	KStdAction::quit(this, TQ_SLOT(slotQuit()), actionCollection())->plug(pm_file);
 	mainMenu->insertItem(i18n("&File"), pm_file);
 
 	// actions
@@ -495,10 +495,10 @@ void MMainWindow::initMainMenu()
 	TDEPopupMenu *pm_settings = new TDEPopupMenu(this);
 	_checkSystemConfigurationAction->plug(pm_settings);
 	pm_settings->insertSeparator();
-	pm_settings->insertItem(SmallIcon("configure_shortcuts"), i18n("Configure Global Shortcuts..."), this, SLOT(slotConfigureGlobalShortcuts()));
-	KStdAction::keyBindings(this, SLOT(slotConfigureShortcuts()), actionCollection())->plug(pm_settings);
+	pm_settings->insertItem(SmallIcon("configure_shortcuts"), i18n("Configure Global Shortcuts..."), this, TQ_SLOT(slotConfigureGlobalShortcuts()));
+	KStdAction::keyBindings(this, TQ_SLOT(slotConfigureShortcuts()), actionCollection())->plug(pm_settings);
 	pm_settings->insertSeparator();
-	KStdAction::configureNotifications(this, SLOT(slotConfigureNotifications()), actionCollection())->plug(pm_settings);
+	KStdAction::configureNotifications(this, TQ_SLOT(slotConfigureNotifications()), actionCollection())->plug(pm_settings);
 	_configureKShutDownAction->plug(pm_settings);
 	mainMenu->insertItem(i18n("&Settings"), pm_settings);
 
@@ -515,28 +515,28 @@ void MMainWindow::initActions()
 	_lockScreenAction = new TDEAction(
 		ks_actions->getName(Action::LockScreen),
 		ks_actions->getIcon(Action::LockScreen), TDEShortcut(),
-		ks_actions, SLOT(slotLockScreen()),
+		ks_actions, TQ_SLOT(slotLockScreen()),
 		ac_shutDown, "kshutdown_lockscreen"
 	);
 
 	_logoutAction = new TDEAction(
 		ks_actions->getName(Action::Logout),
 		ks_actions->getIcon(Action::Logout), TDEShortcut(),
-		ks_actions, SLOT(slotLogout()),
+		ks_actions, TQ_SLOT(slotLogout()),
 		ac_shutDown, "kshutdown_logout"
 	);
 
 	_rebootAction = new TDEAction(
 		ks_actions->getName(Action::Reboot),
 		ks_actions->getIcon(Action::Reboot), TDEShortcut(),
-		ks_actions, SLOT(slotReboot()),
+		ks_actions, TQ_SLOT(slotReboot()),
 		ac_shutDown, "kshutdown_reboot"
 	);
 
 	_shutDownAction = new TDEAction(
 		ks_actions->getName(Action::ShutDown),
 		ks_actions->getIcon(Action::ShutDown), TDEShortcut(),
-		ks_actions, SLOT(slotShutDown()),
+		ks_actions, TQ_SLOT(slotShutDown()),
 		ac_shutDown, "kshutdown_shutdown"
 	);
 
@@ -545,7 +545,7 @@ void MMainWindow::initActions()
 	_cancelAction = new TDEAction(
 		i18n("C&ancel"),
 		"cancel", TDEShortcut(Key_Escape),
-		this, SLOT(slotCancel()),
+		this, TQ_SLOT(slotCancel()),
 		actionCollection(), "kshutdown_cancelaction"
 	);
 	_cancelAction->setEnabled(false);
@@ -553,16 +553,16 @@ void MMainWindow::initActions()
 	_checkSystemConfigurationAction = new TDEAction(
 		i18n("Check &System Configuration"),
 		"button_ok", TDEShortcut(),
-		this, SLOT(slotCheckSystemConfig()),
+		this, TQ_SLOT(slotCheckSystemConfig()),
 		actionCollection(), "kshutdown_checksystemconfiguration"
 	);
 
-	_configureKShutDownAction = KStdAction::preferences(this, SLOT(slotConfigureKShutDown()), actionCollection());
+	_configureKShutDownAction = KStdAction::preferences(this, TQ_SLOT(slotConfigureKShutDown()), actionCollection());
 
 	_startAction = new TDEAction(
 		i18n("&Start"),
 		"button_ok", TDEShortcut(Key_Return),
-		this, SLOT(slotStart()),
+		this, TQ_SLOT(slotStart()),
 		actionCollection(), "kshutdown_startaction"
 	);
 	MiscUtils::plug(_startAction, b_startStop);
@@ -570,7 +570,7 @@ void MMainWindow::initActions()
 	_statisticsAction = new TDEAction(
 		i18n("&Statistics"),
 		TDEShortcut(Key_F2),
-		this, SLOT(slotStats()),
+		this, TQ_SLOT(slotStats()),
 		actionCollection(), "kshutdown_statistics"
 	);
 
@@ -583,25 +583,25 @@ void MMainWindow::initActions()
 		"kshutdown_shutdown",
 		ks_actions->getName(Action::ShutDown),
 		TQString(),
-		0, 0, ks_actions, SLOT(slotShutDown())
+		0, 0, ks_actions, TQ_SLOT(slotShutDown())
 	);
 	_globalAccel->insert(
 		"kshutdown_reboot",
 		ks_actions->getName(Action::Reboot),
 		TQString(),
-		0, 0, ks_actions, SLOT(slotReboot())
+		0, 0, ks_actions, TQ_SLOT(slotReboot())
 	);
 	_globalAccel->insert(
 		"kshutdown_lockscreen",
 		ks_actions->getName(Action::LockScreen),
 		TQString(),
-		0, 0, ks_actions, SLOT(slotLockScreen())
+		0, 0, ks_actions, TQ_SLOT(slotLockScreen())
 	);
 	_globalAccel->insert(
 		"kshutdown_logout",
 		ks_actions->getName(Action::Logout),
 		TQString(),
-		0, 0, ks_actions, SLOT(slotLogout())
+		0, 0, ks_actions, TQ_SLOT(slotLogout())
 	);
 	_globalAccel->readSettings();
 	_globalAccel->updateConnections();
@@ -623,7 +623,7 @@ TQWidget *MMainWindow::initWidgets()
 	cb_actions->insertItem(ks_actions->getIcon(Action::Logout), ks_actions->getName(Action::Logout));
 	cb_actions->insertItem(ks_actions->getIcon(Action::Extras), i18n("Extras"));
 	TQWhatsThis::add(cb_actions, i18n("Select an action to perform at the selected time."));
-	connect(cb_actions, SIGNAL(activated(int)), SLOT(slotActionChange(int)));
+	connect(cb_actions, TQ_SIGNAL(activated(int)), TQ_SLOT(slotActionChange(int)));
 
 	// extras
 	ks_extras->createButton(gb_actions);
@@ -642,14 +642,14 @@ TQWidget *MMainWindow::initWidgets()
 		TQWhatsThis::add(cb_delayTypes, i18n("Disabled by the Administrator."));
 	else
 		TQWhatsThis::add(cb_delayTypes, i18n("Select the type of delay."));
-	connect(cb_delayTypes, SIGNAL(activated(int)), SLOT(slotDelayTypeChange(int)));
+	connect(cb_delayTypes, TQ_SIGNAL(activated(int)), TQ_SLOT(slotDelayTypeChange(int)));
 
 	// date/time edit
 	_dateTimeEdit = new TQDateTimeEdit(gb_delayValues, "TQDateTimeEdit::_dateTimeEdit");
 	_dateTimeEdit->setAutoAdvance(true);
 	_dateTimeEdit->dateEdit()->setMinValue(TQDate::currentDate());
 	setDate(TQDate::currentDate());
-	connect(_dateTimeEdit, SIGNAL(valueChanged(const TQDateTime &)), SLOT(slotUpdateTimeInfo()));
+	connect(_dateTimeEdit, TQ_SIGNAL(valueChanged(const TQDateTime &)), TQ_SLOT(slotUpdateTimeInfo()));
 
 	// app observer/killer
 	_appObserver = new AppObserver(gb_delayValues);
